/*
Dual Temperature Dipslay
using a SHT21 and an LM19

5/2011
http://www.kerrywong.com
*/

#include <LiquidCrystal.h>
#include <Wire.h>
#include <SHT2x.h>

const int pinRS = 2;
const int pinEn = 3;
const int pinBACKLIGHT = 12;
const int pinD4 = 4;
const int pinD5 = 11;
const int pinD6 = 10;
const int pinD7 = 9;

const int pinSwitch = 5;

int currentMode = 0;

LiquidCrystal lcd(pinRS, pinEn, pinD4, pinD5, pinD6, pinD7);
SHT2x sht2x = SHT2x();

float tempC1, tempF1, tempC2, tempF2, humidity;

void setup() {
  tempC1 = 0.0;
  tempF1 = 0.0;
  tempC2 = 0.0;
  tempF2 = 0.0;

  Serial.begin(9600);
  pinMode(pinBACKLIGHT, OUTPUT);
  pinMode(pinSwitch, INPUT);
  digitalWrite(pinSwitch, HIGH);
  lcd.begin(16, 2);
  digitalWrite(pinBACKLIGHT, HIGH); 
}

void getTemperature0() {
  int sensorValue = 0;

  for (int i = 0; i < 5; i++) {
    sensorValue += analogRead(0);
    delay(20);
  }

  float vin = 1.0 * sensorValue / 1024.0;
  tempC1 = (1.8663 - vin) / 0.01169;
  tempF1 = 1.8 * tempC1 + 32.0 - 4.7;
}

void displayTemp0(int dispMode)
{
  char s[] = "A        ";

  if (dispMode == 0) {
    lcd.setCursor(0,0);
    lcd.print("Temp A");
    lcd.setCursor(3, 1);
    lcd.print(tempF1, 1);
  } 
  else if (dispMode == 1) {
    lcd.setCursor(0,0);
    lcd.print(s);
    lcd.setCursor(3, 0);
    lcd.print(tempF1, 1);
    lcd.print(" Humidity");
  }
}

void getTemperature1() {
  humidity = sht2x.GetHumidity();
  tempC2 = sht2x.GetTemperature();
  tempF2 = 1.8 * tempC2 + 32.0;
}

void displayTemp1(int dispMode)
{
  char s[] = "B                ";

  if (dispMode == 0) {
        lcd.setCursor(0,0);
    lcd.print("Temp B  Humidity");
    lcd.setCursor(3, 1);
    lcd.print(tempF2, 1);
    lcd.print("        ");
    lcd.setCursor(10, 1);
    lcd.print(humidity, 1);
    lcd.print("%");
  } 
  else if (dispMode == 1) {
    lcd.setCursor(0,1);
    lcd.print(s);
    lcd.setCursor(3, 1);
    lcd.print(tempF2, 1);
    lcd.print("        ");
    lcd.setCursor(10, 1);
    lcd.print(humidity, 1);
    lcd.print("%");
  }
}

void loop() {
  if (digitalRead(pinSwitch) == LOW) {
    delay(25);
    if (digitalRead(pinSwitch) == LOW) {
      lcd.clear();
      currentMode++;   
      if (currentMode > 2) currentMode = 0;      
    }
  }

  switch (currentMode)
  {
  case 0:

    getTemperature0();
    displayTemp0(0);

    break;
  case 1:
    getTemperature1();
    displayTemp1(0);
    break;
  case 2:
    getTemperature0();
    displayTemp0(1);
    getTemperature1();
    displayTemp1(1);
    break;
  default:   
    break;  
  }

  delay(100);
  Serial.println(digitalRead(pinSwitch));
}



